

##### News Sources and Materials
- [Live Tracker Map](https://gisanddata.maps.arcgis.com/apps/opsdashboard/index.html#/bda7594740fd40299423467b48e9ecf6)
- [How To Stay Safe](https://www.who.int/emergencies/diseases/novel-coronavirus-2019/advice-for-public)
- [Latest Google News Feed](https://www.google.com/search?q=coronavirus&tbm=nws&sxsrf=ACYBGNTsjxRI2IRU0X88bcksb5doQCKzDA:1580388795464&source=lnt&tbs=qdr:d&sa=X&ved=0ahUKEwjiwYqGr6vnAhWYUt4KHQZQB-QQpwUIIA&biw=2133&bih=1052&dpr=0.9)

